@@ -136,6 +136,7 @@ class HubClient(OCSClient):
             print("@ --- authorization granted ---")
 
         self.__options = options
+        self.__debug = debug
         data_file = hub_data if os.path.isfile(hub_data) else default_hub_data
         if data_file != default_hub_data:
             print(f"@ Hub data file: {data_file}")
@@ -291,10 +292,10 @@ class HubClient(OCSClient):
                 item.Metadata["asset_id"],
                 item.Metadata["column_name"],
                 ocstype2hub.get(item.TypeId, "Float"),
-                item.Metadata.get("engunits", "-n/a-"),
+                item.Metadata.get("engunits", "-n/a-").replace("Â", ""),
                 item.Name,
             ]
-        return df.sort_values("Column_Name")
+        return df.sort_values(["Column_Name", "Asset_Id"])
 
     @backoff.on_exception(
         backoff.expo, SdsError, max_tries=6, jitter=backoff.full_jitter
@@ -411,7 +412,7 @@ class HubClient(OCSClient):
                     print("#", end="")
                     continue
                 if "408:" not in str(e):
-                    print(f"[restart-{str(e)[4:6]}]", end="")
+                    print(f"[restart-{str(e)[3:6]}]", end="")
                     raise SdsError50x
                 df = pd.DataFrame()
                 next_page = None
@@ -466,15 +467,15 @@ class HubClient(OCSClient):
         dv_query = gql(
             """
 query(
-    $dataview_id: ID, 
-    $namespace_id: String!, 
-    $start_index: String!, 
+    $dataview_id: ID,
+    $namespace_id: String!,
+    $start_index: String!,
     $end_index: String!,
     $interval: String!,
     $next_page: String
     ) {
   DataView(id: $dataview_id) {
-    id 
+    id
     interpolated(
       namespace: $namespace_id
       startIndex: $start_index
@@ -510,6 +511,8 @@ query(
             raise rh
         except requests.ConnectionError as rc:
             print("&", end="")
+            if self.__debug:
+                print(f"[{rc}]")
             raise rc
         except Exception as e:
             print("!", end="")
